Blob Blame History Raw
--- libhdfspp_ep/lib/common/util.h.orig	2021-08-31 10:12:36.331548291 -0400
+++ libhdfspp_ep/lib/common/util.h	2021-08-31 10:13:17.271857838 -0400
@@ -49,7 +49,7 @@
 // Determine size of buffer that needs to be allocated in order to serialize msg
 // in delimited format
 static inline int DelimitedPBMessageSize(const ::google::protobuf::MessageLite *msg) {
-  size_t size = msg->ByteSize();
+  size_t size = msg->ByteSizeLong();
   return ::google::protobuf::io::CodedOutputStream::VarintSize32(size) + size;
 }
 
--- libhdfspp_ep/lib/rpc/rpc_connection_impl.cc.orig	2021-09-01 09:50:08.587701925 -0400
+++ libhdfspp_ep/lib/rpc/rpc_connection_impl.cc	2021-09-01 09:50:35.856233304 -0400
@@ -55,7 +55,7 @@
 
   std::for_each(
       headers.begin(), headers.end(), [&buf](const pb::MessageLite *v) {
-        buf = pbio::CodedOutputStream::WriteVarint32ToArray(v->ByteSize(), buf);
+        buf = pbio::CodedOutputStream::WriteVarint32ToArray(v->ByteSizeLong(), buf);
         buf = v->SerializeWithCachedSizesToArray(buf);
       });
 
--- libhdfspp_ep/lib/rpc/request.cc.orig	2021-09-01 09:51:25.397381922 -0400
+++ libhdfspp_ep/lib/rpc/request.cc	2021-09-01 09:51:56.745843185 -0400
@@ -62,7 +62,7 @@
 
   std::for_each(
       headers.begin(), headers.end(), [&buf](const pb::MessageLite *v) {
-        buf = pbio::CodedOutputStream::WriteVarint32ToArray(v->ByteSize(), buf);
+        buf = pbio::CodedOutputStream::WriteVarint32ToArray(v->ByteSizeLong(), buf);
         buf = v->SerializeWithCachedSizesToArray(buf);
       });
 
@@ -78,7 +78,7 @@
   pbio::CodedOutputStream os(&ss);
   uint8_t *buf = os.GetDirectBufferForNBytesAndAdvance(len);
   assert(buf);
-  buf = pbio::CodedOutputStream::WriteVarint32ToArray(header->ByteSize(), buf);
+  buf = pbio::CodedOutputStream::WriteVarint32ToArray(header->ByteSizeLong(), buf);
   buf = header->SerializeWithCachedSizesToArray(buf);
 }
 
--- libhdfspp_ep/lib/rpc/cyrus_sasl_engine.cc.orig	2017-08-30 10:56:51.000000000 -0400
+++ libhdfspp_ep/lib/rpc/cyrus_sasl_engine.cc	2021-09-01 13:55:08.886606370 -0400
@@ -121,10 +121,10 @@
   // Create an array of callbacks that embed a pointer to this
   //   so we can call methods of the engine
   per_connection_callbacks_ = {
-    { SASL_CB_USER,     (sasl_callback_ft) & get_name, this}, // userid for authZ
-    { SASL_CB_AUTHNAME, (sasl_callback_ft) & get_name, this}, // authid for authT
-    { SASL_CB_GETREALM, (sasl_callback_ft) & getrealm, this}, // krb/gssapi realm
-    //  { SASL_CB_PASS,        (sasl_callback_ft)&getsecret,  this
+    { SASL_CB_USER,     reinterpret_cast<sasl_callback_ft &>(get_name), this}, // userid for authZ
+    { SASL_CB_AUTHNAME, reinterpret_cast<sasl_callback_ft &>(get_name), this}, // authid for authT
+    { SASL_CB_GETREALM, reinterpret_cast<sasl_callback_ft &>(getrealm), this}, // krb/gssapi realm
+    //  { SASL_CB_PASS,     reinterpret_cast<sasl_callback_ft>(getsecret), this},
     { SASL_CB_LIST_END, (sasl_callback_ft) NULL, NULL}
   };
 }
@@ -420,9 +420,9 @@
 
 
 const sasl_callback_t per_process_callbacks[] = {
-    { SASL_CB_LOG, (sasl_callback_ft) & sasl_my_log, NULL},
-    { SASL_CB_GETOPT, (sasl_callback_ft) & sasl_getopt, NULL},
-    { SASL_CB_GETPATH, (sasl_callback_ft) & get_path, NULL}, // to find th mechanisms
+    { SASL_CB_LOG, reinterpret_cast<sasl_callback_ft &>(sasl_my_log), NULL},
+    { SASL_CB_GETOPT, reinterpret_cast<sasl_callback_ft &>(sasl_getopt), NULL},
+    { SASL_CB_GETPATH, reinterpret_cast<sasl_callback_ft &>(get_path), NULL}, // to find th mechanisms
     { SASL_CB_LIST_END, (sasl_callback_ft) NULL, NULL}
   }; // callbacks_ array